<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Network Assistant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="76"/>
        <source>IP address</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Hardware detected</source>
        <translation>Hardware rilevato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.ui" line="389"/>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Re-scan</source>
        <translation>Ri-scansiona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Active interface</source>
        <translation>Interfaccia attiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>WiFi status</source>
        <translation>WiFi status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Sblocca tutti i dispositivi software/hardware wireless chiusi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Unblock WiFi Devices</source>
        <translation>Sblocca i Dispositivi WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Linux drivers</source>
        <translation>Linux drivers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Associated Linux drivers</source>
        <translation>Drivers Linux associati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Load Driver</source>
        <translation>Carica Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Unload Driver</source>
        <translation>Scarica Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Blacklist Driver</source>
        <translation>Metti Driver in Blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Windows drivers</source>
        <translation>Drivers Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Available Windows drivers</source>
        <translation>Drivers Windows disponibili</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Remove Driver</source>
        <translation>Rimuovi Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>Add Driver</source>
        <translation>Aggiungi Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>About NDISwrapper</source>
        <translation>Informazioni su NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Install NDISwrapper</source>
        <translation>Installa NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Per poter utilizzare i driver Windows è necessario prima installare NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Disinstalla NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Net diagnostics</source>
        <translation>Diagnostica di rete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <location filename="../mainwindow.ui" line="725"/>
        <source>Target URL:</source>
        <translation>URL del Target:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="619"/>
        <source>Packets</source>
        <translation>Pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <location filename="../mainwindow.ui" line="797"/>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <location filename="../mainwindow.ui" line="811"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="866"/>
        <source>About...</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="889"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="957"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="964"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>IP address from router:</source>
        <translation>Indirizzo IP dal router:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>External IP address:</source>
        <translation>Indirizzo IP esterno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="227"/>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Copy &amp;All</source>
        <translation>Copia &amp;Tutto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <location filename="../mainwindow.cpp" line="230"/>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute non è installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute non è installato, vuoi installarlo ora?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute non è stato installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Traceroute non può essere installato. Questo probabilmente significa che stai usando il LiveCD o che non ti è possibile collegarti ai repository del software.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute  non è installato e, poichè non si riesce a rilevare alcuna connessione internet, al momento non si può intallare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>No destination host</source>
        <translation>Nessun host di destinazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Please fill in the destination host field</source>
        <translation>Compilare il campo dell&apos;host di destinazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Loaded Drivers</source>
        <translation>Drivers caricati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Unloaded Drivers</source>
        <translation>Drivers non caricati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Blacklisted Drivers</source>
        <translation>Drivers in Blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Blacklisted Broadcom Drivers</source>
        <translation>Drivers Broadcom messi in Blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1009"/>
        <source>enabled</source>
        <translation>abilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>disabled</source>
        <translation>disabilitato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1015"/>
        <source>WiFi hardware switch is off</source>
        <translation>L a scheda WiFi è spenta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Individua la posizione del driver di Windows che desideri aggiungere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1023"/>
        <source>Windows installation information file (*.inf)</source>
        <translation> File (*.inf) d&apos;informazione di installazione di Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>*.sys file not found</source>
        <translation>File *.sys non trovato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>I files *.sys dovrebbero essere nella stessa posizione del file *.inf. %1 non si riesce a trovare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>sys file reference not found</source>
        <translation>il file sys di referenza non si trova</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Il file sys per il driver non può essere determinato dopo l&apos;analisi del file inf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Il driver Ndiswrapper è stato rimosso.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1093"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1132"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1137"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Network Assistant</source>
        <translation type="vanished">Info su MX Network Assistant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1133"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1134"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Programma di MX Linux per la configurazione e risoluzione dei problemi di rete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1136"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Copyright (c) MEPIS LLC e MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenza</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>You must run this program as root.</source>
        <translation>Devi eseguire questo programma come amministratore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper non è installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>driver installed</source>
        <translation>driver installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source> and in use by </source>
        <translation>e in uso da</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <source>. Alternate driver: </source>
        <translation>Cambiare driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Driver removed from blacklist</source>
        <translation>Driver rimosso dalla blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Driver removed from blacklist.</source>
        <translation>Driver rimosso dalla blacklist.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Module blacklisted</source>
        <translation>Modulo messo in blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>Installation successful</source>
        <translation>Installazione completata con successo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="893"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>E&apos; incorso un errore, non è possibile compilare il driver ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="898"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>E&apos; incorso un errore, non è possibile installare ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>E&apos; incorso un errore durante la rimozione di Ndiswrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="968"/>
        <source>Unblacklist Driver</source>
        <translation>Togli Driver da Blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="973"/>
        <source>Blacklist Driver</source>
        <translation>Metti Driver in Blacklist</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1115"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Non si riesce a sbloccare i dispositivi.
Il dispositivo/i WiFi  potrebbe essere già sbloccato/i.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1117"/>
        <source>WiFi devices unlocked.</source>
        <translation>Dispositivi WiFi sbloccati.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1162"/>
        <location filename="../mainwindow.cpp" line="1163"/>
        <source>Driver loaded successfully</source>
        <translation>Driver caricato con successo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1181"/>
        <location filename="../mainwindow.cpp" line="1182"/>
        <source>Driver unloaded successfully</source>
        <translation>Driver scaricato con successo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="715"/>
        <source>Could not load </source>
        <translation>Impossibile caricare</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source>Could not unload </source>
        <translation>Impossibile scaricare</translation>
    </message>
</context>
</TS>
